@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2023 Romain Brault <mail@romainbrault.com>
+# SPDX-FileCopyrightText: © 2023 Romain Brault <mail@romainbrault.com>
 #
 # SPDX-License-Identifier: MIT
 """Localization."""
@@ -8,10 +8,14 @@ import pathlib
 
 
 LOCALE_DIRECTORY = pathlib.Path(__file__).parent / "locale"
+"""Path to the directoryc containing the locales."""
+
 TRANSLATION = gettext.translation(
     "messages",
     LOCALE_DIRECTORY,
     fallback=True,
 )
+"""A Gettext translation."""
+
 _ = TRANSLATION.gettext
-"""Convenient access to gettext."""
+"""Convenient access to the translation's gettext."""
